# API Reference

This page provides an auto-generated summary of xcollection’s API.
For more details and examples, refer to the relevant chapters in the main part of the documentation.

## Collection

```{eval-rst}

.. autosummary:: xcollection.main.Collection
.. autosummary:: xcollection.main.open_collection

.. autoclass:: xcollection.main.Collection
    :members:

.. autofunction:: xcollection.main.open_collection
```
